"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
const {
  Logger
} = require("../../../utils/logger");
class Execution {
  constructor(lintHandler, metricsHandler, cliArguments) {
    this._cliArguments = cliArguments;
    this.lint = new lintHandler(cliArguments);
    this.metric = new metricsHandler(cliArguments);
  }

  /**
   * @function executeLintHandler -  Linter Handler
   * @returns {Promise<any>} - return a Handle a Lint  with specific requirement
   */

  async executeLintHandler() {
    try {
      return await this.lint.executeAnalysis();
    } catch (error) {
      Logger.log(Logger.FAILURE_TYPE, `Error executing  analysis: ${error}`);
      throw error;
    }
  }

  /**
   * @function executeMetricHandler -  Report metrics Handler
   * @returns {void}
   */
  executeMetricHandler() {
    try {
      this.metric.executeAnalysis();
    } catch (error) {
      Logger.log(Logger.FAILURE_TYPE, `Error executing  analysis: ${error}`);
      throw error;
    }
  }
}
var _default = exports.default = Execution;