"use strict";

const {
  program
} = require('commander');
const path = require("path");
const {
  Logger
} = require('./utils/logger');
const {
  existsSync
} = require('fs');
function showHelperCmds() {
  const packageJsonPath = path.resolve(process.cwd(), 'package.json');

  // Check if --version flag is passed and package.json exists
  if (existsSync(packageJsonPath) && process.argv.includes('--version')) {
    const {
      name,
      version
    } = require(packageJsonPath);

    // Logging the version correctly
    Logger.log(Logger.SUCCESS_TYPE, `${name} Version: ${version}`);
    program.version(version || '0.0.1');
    return;
  }
  Logger.log(Logger.SUCCESS_TYPE, 'Supported Commands:');

  // Set the name of the CLI
  program.name('npx ZDLintingFramework');

  // Define commands
  program.command("lint").description("Lint directory and files locally.");
  program.command("lint-ci").description("Lint files in CI with optional SonarQube integration.");
  program.command("check-locally").description("Lint files locally with optional SonarQube integration.");
  program.command("init").description("Initialize configuration file.");
  program.command("help").description("Display list of supported commands.");

  // Add global options
  program.option('--dir <path>', "Specify directory or file to lint (Usage: npx ZDLintingFramework lint --dir=path/to/file)");

  // Parse the arguments passed to the CLI
  program.parse(process.argv);
}
showHelperCmds();
module.exports = {
  showHelperCmds
};