"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _runEslint = require("../core/eslint/runEslint.js");
var _Eslint = _interopRequireDefault(require("../core/handlers/libraryInterface/Eslint"));
var _Execution = _interopRequireDefault(require("../core/handlers/libraryInterface/Execution"));
var _SonarQube = _interopRequireDefault(require("../core/handlers/libraryInterface/SonarQube"));
var _helper = require("../setup/helper.js");
var _initialSetup = require("../setup/initialSetup");
var _cliArgsToObject = require("../utils/cliArgsToObject");
var _fileUtils = require("../utils/fileUtils.js");
var _request = require("../utils/request");
/**
 *
 * @function startLinterAnalysis
 * @description -  this function start linter analysis process and initial setup
 * @return {Promise<void>}
 */

async function startLinterAnalysis() {
  global.analytics = {
    reportStatus: true,
    pipelineStatus: "passed",
    sonarQubeStatus: true
  };
  const [,, action, ...option] = process.argv;
  switch (action) {
    case "lint":
      {
        (0, _fileUtils.checkConfigurationFileExist)();
        const $cliObjects = (0, _cliArgsToObject.cliArgsToObject)(option);
        $cliObjects.env = "dev";
        $cliObjects.cmdExecuted = action;
        const execute = new _Execution.default(_Eslint.default, _SonarQube.default, $cliObjects);
        await execute.executeLintHandler().finally(() => {
          execute.executeMetricHandler();
        });
        break;
      }
    case "lint-ci":
    case "local":
      {
        (0, _fileUtils.checkConfigurationFileExist)();
        (0, _request.createBranchDiff)();
        const $cliObjects = (0, _cliArgsToObject.cliArgsToObject)(option);
        $cliObjects.env = "ci";
        $cliObjects.cmdExecuted = action;
        const execute = new _Execution.default(_Eslint.default, _SonarQube.default, $cliObjects);
        await execute.executeLintHandler().finally(() => {
          execute.executeMetricHandler();
        });
        break;
      }
    case "fix":
      {
        (0, _runEslint.fixEslintIssue)(option);
        break;
      }
    case "init":
      {
        (0, _initialSetup.setupDefaultConfiguration)();
        break;
      }
    case "check":
      {
        (0, _fileUtils.checkConfigurationFileExist)();
        require("../core/eslint/ErrorBetweenBranches");
        break;
      }
    case "help":
      {
        (0, _helper.consoleHelperCommands)();
        break;
      }
    default:
      {
        (0, _helper.consoleHelperCommands)();
        break;
      }
  }
}
startLinterAnalysis();